@@ -397,11 +397,11 @@ class FrescoApp(RouteCollection):
 
     def requestcontext_put(self, *args, **kwargs):
         kwargs['REQUEST_METHOD'] = 'PUT'
-        return self.requestcontext_post(*args, **kwargs)
+        return self.requestcontext_with_payload(*args, **kwargs)
 
     def requestcontext_patch(self, *args, **kwargs):
         kwargs['REQUEST_METHOD'] = 'PATCH'
-        return self.requestcontext_post(*args, **kwargs)
+        return self.requestcontext_with_payload(*args, **kwargs)
 
     def requestcontext_delete(self, *args, **kwargs):
         kwargs['REQUEST_METHOD'] = 'DELETE'
