@@ -36,7 +36,7 @@ class XForwarded(object):
     Example::
 
         >>> from fresco import FrescoApp, context, GET, Response
-        >>> from flea import TestAgent
+        >>> from flea import Agent
         >>> app = FrescoApp()
         >>> @app.route('/', GET)
         ... def view():
@@ -44,7 +44,7 @@ class XForwarded(object):
         ...                      "; REMOTE_ADDR is ",
         ...                      context.request.remote_addr])
         ...
-        >>> r = TestAgent(XForwarded(app))
+        >>> r = Agent(XForwarded(app))
         >>> response = r.get('/',
         ...     SERVER_NAME='wsgiserver-name',
         ...     SERVER_PORT='8080',
