@@ -161,7 +161,7 @@ class RequestArg(RouteArg):
             value = self.getter(self.source(request))
         except KeyError:
             if self.required:
-                value = LazyException(
+                return LazyException(
                             self.exception('No value provided for %s' %
                                            (self.formkey,)))
             else:
