@@ -1,7 +1,7 @@
 import re
 import sys
+from copy import copy
 from collections import namedtuple
-from functools import partial
 
 from fresco.compat import string_types
 from fresco.exceptions import ResponseException
@@ -56,6 +56,13 @@ RouteTraversal = namedtuple('RouteTraversal',
 _marker = object()
 
 
+class RouteNotReady(RuntimeError):
+    """
+    getview was called on a route mapping to an instance method, but the
+    class has yet been instantiated
+    """
+
+
 class URLGenerationError(Exception):
     """\
     Was not possible to generate the requested URL.
@@ -658,6 +665,8 @@ class Route(object):
             return self._view
         uview = self.viewspec
         if isinstance(uview, string_types):
+            if self.instance is None:
+                raise RouteNotReady()
             uview = getattr(self.instance, uview)
 
         self._view = uview
@@ -697,10 +706,10 @@ class Route(object):
         Use this when traversing view classes.
         """
         cls = self.__class__
-        copy = cls.__new__(cls)
-        copy.__dict__ = self.__dict__.copy()
-        copy._setinstance(instance)
-        return copy
+        ob = cls.__new__(cls)
+        ob.__dict__ = self.__dict__.copy()
+        ob._setinstance(instance)
+        return ob
 
     def _setinstance(self, instance):
         self.instance = instance
@@ -738,7 +747,11 @@ class Route(object):
         """
         if self.name:
             yield self.name
-        view = self.getview()
+        yield self.viewspec
+        try:
+            view = self.getview()
+        except RouteNotReady:
+            return
         yield view
 
         # Also return the underlying function object for python2 unbound
@@ -814,20 +827,45 @@ class RouteCollection(object):
             for item in routes:
                 self.add_route(item)
 
+    def __add__(self, other):
+        result = copy(self)
+        for item in other:
+            result.add_route(item)
+        return result
+
+    def __iter__(self):
+        return iter(self.__routes__)
+
     def add_route(self, route):
         self.__routes__.append(route)
-        self._add_url_method(route.getview(), route)
+        try:
+            view = route.getview()
+        except RouteNotReady:
+            # If view methods are referenced by name in a class's __routes__
+            # attribute, and the class has not yet been instantiated, this will
+            # fail. However the view.url method is now deprecated, so we
+            # can ignore this case.
+            pass
+        else:
+            self._add_url_method(view, route)
 
     def _add_url_method(self, func, route):
         """\
         Add a method available at ``func.url`` that returns a URL generated
         from the given route
         """
-        from fresco.core import urlfor
         if hasattr(func, 'url'):
             return
+
+        def _urlfor(*args, **kwargs):
+            import warnings
+            from fresco.core import urlfor
+            warnings.warn(
+                "%r.url() is deprecated. Please use urlfor() instead",
+                DeprecationWarning, stacklevel=2)
+            return urlfor(func, *args, **kwargs)
         try:
-            func.url = partial(urlfor, func)
+            func.url = _urlfor
         except AttributeError:
             # Cannot set function attributes on bound or unbound methods.
             # See http://www.python.org/dev/peps/pep-0232/
@@ -1073,6 +1111,39 @@ class RouteCollection(object):
         self.add_route(route)
         return route
 
+    def replace(self, viewspec, newroute):
+        """
+        Replace the route(s) identified by ``viewspec`` with a new
+        Route.
+
+        :param viewspec: The routed view callable, or its fully qualified name
+                         ('package.module.view_function'), or the name of a
+                         named route
+        :param newroute: The replacement route. This may be None, in which
+                         case the route will be removed without replacement
+        """
+        route = self.routefor(viewspec)
+
+        if newroute:
+            position = self.__routes__.index(route)
+            self.__routes__[position] = newroute
+        else:
+            self.__routes__.remove(route)
+
+        for k, r in list(self.__routed_views__.items()):
+            if r is route:
+                del self.__routed_views__[k]
+
+    def remove(self, viewspec):
+        """
+        Remove the route(s) identified by ``viewspec``
+
+        :param viewspec: The routed view callable, or its fully qualified name
+                         ('package.module.view_function'), or the name of a
+                         named route
+        """
+        self.replace(viewspec, None)
+
 
 class DelegateRoute(Route):
     """\
