@@ -350,9 +350,15 @@ class TestAppRequestContext(object):
 
     def test_it_posts_data(self):
         with FrescoApp().requestcontext_post(data={'foo': 'bar'}) as c:
+            assert c.request.method == 'POST'
             assert list(c.request.form.allitems()) == [('foo', 'bar')]
             assert list(c.request.query.allitems()) == []
 
+    def test_it_puts_data(self):
+        with FrescoApp().requestcontext_put(data={'foo': 'bar'}) as c:
+            assert c.request.method == 'PUT'
+            assert list(c.request.form.allitems()) == [('foo', 'bar')]
+
     def test_it_posts_data_multipart(self):
         with FrescoApp().requestcontext_post(
                 files=[('foo', 'foo.txt', 'text/plain', b'bar')]) as c:
