@@ -1,5 +1,5 @@
 import pytest
-from flea import TestAgent
+from flea import Agent
 
 from fresco import FrescoApp, GET, Response
 from fresco.requestcontext import RequestContext
@@ -23,7 +23,7 @@ class TestRequestContext(object):
         app = FrescoApp()
         app.route('/', GET, view)
 
-        assert TestAgent(app).get('/').body == ''
+        assert Agent(app).get('/').body == ''
 
     def test_context_returns_correct_request_for_each_app(self):
 
@@ -53,7 +53,7 @@ class TestRequestContext(object):
         app = FrescoApp()
         app.route('/', GET, view)
 
-        threads = [Thread(target=partial(TestAgent(app).get, '/'))
+        threads = [Thread(target=partial(Agent(app).get, '/'))
                    for i in range(threadcount)]
 
         for t in threads:
