@@ -1,3 +1,4 @@
+import sys
 import os
 import re
 from calendar import timegm
@@ -58,6 +59,19 @@ class TestServeStaticFile():
             response = serve_static_file(self.tmpname)
         assert response.status_code == 304
 
+    def test_it_doesnt_fail_with_an_out_of_range_modified_since_value1(self):
+        year = sys.maxsize
+        with FrescoApp().requestcontext(
+                HTTP_IF_MODIFIED_SINCE='"Wed, 09 Feb %s 04:46:40 GMT"' % year):
+            response = serve_static_file(self.tmpname)
+        assert response.status_code == 400
+
+    def test_it_doesnt_fail_with_an_out_of_range_modified_since_value2(self):
+        with FrescoApp().requestcontext(
+                HTTP_IF_MODIFIED_SINCE='"Wed, 01 Feb -2001 04:46:40 GMT"'):
+            response = serve_static_file(self.tmpname)
+        assert response.status_code == 400
+
     def test_last_modified_format_is_correct(self):
         with FrescoApp().requestcontext():
             response = serve_static_file(self.tmpname)
@@ -73,3 +87,14 @@ class TestServeStaticFile():
             serve_static_file(self.tmpname)
 
         file_wrapper.assert_called_once()
+
+    def test_it_returns_not_found(self):
+        with FrescoApp().requestcontext():
+            response = serve_static_file(self.tmpname + 'x')
+        assert response.status_code == 404
+
+    def test_it_returns_forbidden(self):
+        with FrescoApp().requestcontext():
+            os.chmod(self.tmpname, 0)
+            response = serve_static_file(self.tmpname)
+        assert response.status_code == 403
