@@ -1,6 +1,6 @@
-from nose.tools import assert_raises
 from fresco.util.common import object_or_404
 from fresco.exceptions import NotFound
+import pytest
 
 
 class TestObjectOr404(object):
@@ -10,9 +10,11 @@ class TestObjectOr404(object):
         assert object_or_404(ob) is ob
 
     def test_it_raises_NotFound(self):
-        assert_raises(NotFound, object_or_404, None)
+        with pytest.raises(NotFound):
+            object_or_404(None)
 
     def test_it_raises_custom_exception(self):
         class Foo(Exception):
             pass
-        assert_raises(Foo, object_or_404, None, exception=Foo)
+        with pytest.raises(Foo):
+            object_or_404(None, exception=Foo)
