@@ -1,4 +1,4 @@
-from flea import TestAgent
+from flea import Agent
 from fresco.util.wsgi import ClosingIterator, StartResponseWrapper
 
 
@@ -69,4 +69,4 @@ class TestStartResponseWrapper(object):
             write2(b'mat')
             return []
 
-        assert TestAgent(wsgiapp).get('/').body == 'catsatmat'
+        assert Agent(wsgiapp).get('/').body == 'catsatmat'
