@@ -1,13 +1,18 @@
 #
 # Copyright (c) 2009-2014 Oliver Cope. All rights reserved.
 # See LICENSE.txt for terms of redistribution and use.
-
 """
 Utilities for working with data on the HTTP level
 """
+from __future__ import absolute_import
+from __future__ import unicode_literals
 
+from binascii import hexlify
 from collections import namedtuple
 from email.message import Message
+from io import BytesIO
+from itertools import chain
+import os
 import re
 try:
     from email.parser import BytesParser
@@ -26,6 +31,7 @@ from fresco.compat import PY3, string_types
 from fresco.exceptions import RequestParseError
 from fresco.util.io import (ExpandableOutput, SizeLimitedInput, PutbackInput,
                             DelimitedInput)
+from fresco.util.wsgi import unicode_to_environ
 
 KB = 1024
 MB = 1024 * KB
@@ -488,3 +494,85 @@ class FileUpload(object):
 
         self.file.seek(0)
         copyfileobj(self.file, fileob)
+
+
+def encode_multipart(data=None, files=None, charset='UTF-8', **kwargs):
+    """
+    Encode ``data`` using multipart/form-data encoding, returning a tuple
+    of ``(<encoded data>, <environ items>)
+
+    :param data: POST data to be encoded, either a dict or list of
+                 ``(name, value)`` tuples.
+
+    :param charset: Encoding used for any unicode values encountered in
+                    ``data``
+
+    :param files: list of ``(name, filename, content_type, data)`` tuples.
+                    ``data`` may be either a byte string, iterator or
+                    file-like object.
+
+    :param kwargs: other data items as keyword arguments
+    :returns: a tuple of ``(<encoded_data>, <environ_items>)``,
+              where ``encoded_data`` is a BytesIO object
+              and ``environ`` is a dict containing the Content-Type and
+              Content-Length headers encoded for inclusion in a WSGI environ
+              dict.
+    """
+
+    def header_block(name):
+        return [('Content-Disposition', 'form-data; name="%s"' % (name,))]
+
+    def file_header_block(name, filename, content_type):
+        return [('Content-Disposition',
+                 'form-data; name="%s"; filename="%s"' % (name, filename)),
+                ('Content-Type', content_type)]
+
+    def write_payload(stream, data):
+        "Write ``data`` to ``stream``, encoding as required"
+        if hasattr(data, 'read'):
+            copyfileobj(data, stream)
+        elif isinstance(data, bytes):
+            stream.write(data)
+        elif isinstance(data, string_types):
+            stream.write(data.encode(charset))
+        else:
+            raise ValueError(data)
+
+    if data is None:
+        data = {}
+
+    if files is None:
+        files = []
+
+    try:
+        data = data.items()
+    except AttributeError:
+        pass
+
+    data = chain(data, kwargs.items())
+
+    boundary = b'-------' + hexlify(os.urandom(16))
+    alldata = chain(
+        ((header_block(k), payload) for k, payload in data),
+        ((file_header_block(k, fn, ct), payload)
+         for k, fn, ct, payload in files))
+
+    CRLF = b'\r\n'
+    post_data = BytesIO()
+    post_data.write(b'--' + boundary)
+    for headers, payload in alldata:
+        post_data.write(CRLF)
+        for name, value in headers:
+            post_data.write('{0}: {1}\r\n'.format(name, value).encode('ascii'))
+        post_data.write(CRLF)
+        write_payload(post_data, payload)
+        post_data.write(b'\r\n--' + boundary)
+    post_data.write(b'--\r\n')
+    length = post_data.tell()
+    post_data.seek(0)
+    wsgienv = {
+        'CONTENT_LENGTH': str(length),
+        'CONTENT_TYPE': unicode_to_environ(
+                'multipart/form-data; boundary=' + boundary.decode('ascii'))}
+
+    return (post_data, wsgienv)
