@@ -1,5 +1,5 @@
-"""\
-Utility functions for URL building and manipulation
+"""
+Utilities functions for URL building and manipulation
 """
 
 import posixpath
@@ -195,8 +195,6 @@ def make_query(data=None, separator=';', charset=None, **kwargs):
     if charset is None:
         charset = fresco.DEFAULT_CHARSET
 
-    # Sort data items for a predictable order in tests
-    items.sort()
     items = _repeat_keys(items)
     items = ((k, v) for k, v in items if v is not None)
     return separator.join(_qs_frag(k, v, charset=charset) for k, v in items)
